==> 0.0.32.tar.gz: lib/src/widgets/navbar_menu.dart <==
import 'package:ametory_ui/src/models/navbar_menu_model.dart';
import 'package:fluentui_icons/fluentui_icons.dart';
import 'package:flutter/material.dart';

import '../../ametory_ui.dart';

class NavbarMenu extends StatelessWidget {
  final List<NavbarMenuModel> menus;
  final EdgeInsets? padding;
  final EdgeInsets? menuPadding;
  final TextStyle? textStyle;
  final TextStyle? currentTextStyle;
  final BoxDecoration? decoration;
  final BoxDecoration? currentDecoration;
  const NavbarMenu(
      {Key? key,
      required this.menus,
      this.padding,
      this.menuPadding,
      this.textStyle,
      this.currentTextStyle,
      this.decoration,
      this.currentDecoration})
      : super(key: key);

  Widget renderMenu(BuildContext context, NavbarMenuModel e) {
    var _textStyle = textStyle ?? MyTypo.bodyText1;
    var _decoration = decoration;
    if (e.isCurrent) {
      _textStyle = currentTextStyle ??
          MyTypo.bodyText1.copyWith(fontWeight: FontWeight.bold);
      _decoration = currentDecoration;
    }
    return Container(
      padding: menuPadding ??
          const EdgeInsets.symmetric(vertical: 10, horizontal: 20),
      // decoration: _decoration,
      child: Row(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          InkWell(
            onTap: e.onTap,
            child: Text(
              e.label,
              style: _textStyle,
            ),
          ),
          if (e.children != null && e.children!.isNotEmpty) hspace(20),
          if (e.children != null && e.children!.isNotEmpty)
            InkWell(
              onTapDown: (details) async {
                final res = await popUpMenu<NavbarMenuModel>(context,
                    offset: details.globalPosition,
                    items: e.children!.map((c) {
                      var _textStyle = textStyle ?? MyTypo.bodyText1;
                      var _decoration = decoration;
                      if (c.isCurrent) {
                        _textStyle = currentTextStyle ??
                            MyTypo.bodyText1
                                .copyWith(fontWeight: FontWeight.bold);
                        _decoration = currentDecoration;
                      }
                      return PopupMenuItem(
                        value: e,
                        child: Container(
                          decoration: _decoration,
                          child: Text(
                            c.label,
                            style: _textStyle,
                          ),
                        ),
                      );
                    }).toList());
                if (res != null && res.onTap != null) {
                  res.onTap!();
                }
              },
              child: const Icon(
                FluentSystemIcons.ic_fluent_chevron_down_regular,
                size: 14,
                color: Colors.grey,
              ),
            )
        ],
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: padding ?? const EdgeInsets.all(0),
      child: Row(
        children: menus.map((e) => renderMenu(context, e)).toList(),
      ),
    );
  }
}

==> 0.0.50.tar.gz: lib/src/widgets/navbar_menu.dart <==
import 'package:ametory_ui/src/models/navbar_menu_model.dart';
import 'package:fluentui_icons/fluentui_icons.dart';
import 'package:flutter/material.dart';

import '../../ametory_ui.dart';

class NavbarMenu extends StatelessWidget {
  final List<NavbarMenuModel> menus;
  final EdgeInsets? padding;
  final EdgeInsets? menuPadding;
  final TextStyle? textStyle;
  final TextStyle? currentTextStyle;
  final BoxDecoration? decoration;
  final BoxDecoration? currentDecoration;
  const NavbarMenu(
      {Key? key, required this.menus, this.padding, this.menuPadding, this.textStyle, this.currentTextStyle, this.decoration, this.currentDecoration})
      : super(key: key);

  Widget renderMenu(BuildContext context, NavbarMenuModel e) {
    var _textStyle = textStyle ?? MyTypo.bodyText1;
    var _decoration = decoration;
    if (e.isCurrent) {
      _textStyle = currentTextStyle ?? MyTypo.bodyText1.copyWith(fontWeight: FontWeight.bold);
      _decoration = currentDecoration;
    }
    return Container(
      padding: menuPadding ?? const EdgeInsets.symmetric(vertical: 10, horizontal: 20),
      // decoration: _decoration,
      child: Row(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          InkWell(
            onTap: e.onTap,
            child: Text(
              e.label,
              style: _textStyle,
            ),
          ),
          if (e.children != null && e.children!.isNotEmpty) hspace(20),
          if (e.children != null && e.children!.isNotEmpty)
            InkWell(
              onTapDown: (details) async {
                final res = await popUpMenu<NavbarMenuModel>(context,
                    offset: details.globalPosition,
                    items: e.children!.map((c) {
                      var _textStyle = textStyle ?? MyTypo.bodyText1;
                      var _decoration = decoration;
                      if (c.isCurrent) {
                        _textStyle = currentTextStyle ?? MyTypo.bodyText1.copyWith(fontWeight: FontWeight.bold);
                        _decoration = currentDecoration;
                      }
                      return PopupMenuItem(
                        value: c,
                        child: Container(
                          decoration: _decoration,
                          child: Text(
                            c.label,
                            style: _textStyle,
                          ),
                        ),
                      );
                    }).toList());
                if (res != null && res.onTap != null) {
                  res.onTap!();
                }
              },
              child: const Icon(
                FluentSystemIcons.ic_fluent_chevron_down_regular,
                size: 14,
                color: Colors.grey,
              ),
            )
        ],
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: padding ?? const EdgeInsets.all(0),
      child: Row(
        children: menus.map((e) => renderMenu(context, e)).toList(),
      ),
    );
  }
}
